@@ -26,7 +26,7 @@ our @ISA = qw(DiaColloDB::Relation);
 ##    ##
 ##    ##-- ddc client options
 ##    ddcServer => "$server:$port",    ##-- ddc server (required; default=$coldb->{ddcServer} via fromDB() method)
-##    ddcTimeout => $timeout,          ##-- ddc timeout; default=120
+##    ddcTimeout => $timeout,          ##-- ddc timeout; default=300
 ##    ddcLimit   => $limit,            ##-- default limit for ddc queries (default=-1)
 ##    ddcSample  => $sample,           ##-- default sample size for ddc queries (default=-1:all)
 ##    dmax    => $maxDistance,         ##-- default distance for near() queries (default=5; 1=immediate adjacency; ~ ddc CQNear.Dist+1)
@@ -40,7 +40,7 @@ sub new {
   my $rel  = $that->SUPER::new(
 			       #base       => undef,
 			       ddcServer  => undef,
-			       ddcTimeout => 120,
+			       ddcTimeout => 300,
 			       ddcLimit   => -1,
 			       ddcSample  => -1,
 			       dmax       => 5,
@@ -197,14 +197,17 @@ sub profile {
     }
   }
 
-  ##-- query independent N
-  my $qstrN   = "count(* #sep)";
-  my $resultN = $rel->ddcQuery($coldb, $qstrN, limit=>1, logas=>'fN');
-  my $N       = $resultN->{counts_}[0][0] * $fcoef;
+  ##-- query independent N (by epoch)
+  my $qstrN   = "COUNT(* #SEP) #BY[".($opts{slice} ? "date/$opts{slice}" : q{@'0'})."]";
+  my $resultN = $rel->ddcQuery($coldb, $qstrN, limit=>-1, logas=>'fN');
+  my %fN      = qw();
+  my $N       = 0; ##-- total N
+  foreach (@{$resultN->{counts_}}) {
+    $fN{$_->[1]} = $_->[0] * $fcoef;
+    $N          += $_->[1] * $fcoef;
+  }
 
   ##-- finalize sub-profiles: label, titles, N, compile
-  my $N1 = 0; $N1 += $_->{f1} foreach (values %y2prf);
-  $N     = $N1 if ($N1 > $N);
   my ($f1);
   foreach $prf (values %y2prf) {
     $prf->{titles} = \@titles;
@@ -215,7 +218,8 @@ sub profile {
       $prf->{f1} = $f1;
     }
 
-    $prf->{N} = $N;
+    $prf->{N} = $fN{$prf->{label}} || $N;
+    $prf->{N} = $f1 if ($f1 > $prf->{N});
     $prf->compile($opts{score}, eps=>$opts{eps});
   }
 
@@ -223,7 +227,7 @@ sub profile {
   if ($opts{fill}) {
     for ($y=$opts{dslo}; $y <= $opts{dshi}; $y += ($opts{slice}||1)) {
       next if (exists($y2prf{$y}));
-      $prf = $y2prf{$y} = DiaColloDB::Profile->new(N=>$N,f1=>0,label=>$y,titles=>\@titles)->compile($opts{score},eps=>$opts{eps});
+      $prf = $y2prf{$y} = DiaColloDB::Profile->new(N=>($fN{$y}||$N||0),f1=>0,label=>$y,titles=>\@titles)->compile($opts{score},eps=>$opts{eps});
     }
   }
 
@@ -402,7 +406,7 @@ sub ddcClient {
   $port   ||= 50000;
 
   return $rel->{dclient} = DDC::Client::Distributed->new(
-							 timeout=>($rel->{ddcTimeout}//120),
+							 timeout=>($rel->{ddcTimeout}//300),
 							 connect=>{PeerAddr=>$server,PeerPort=>$port},
 							 mode=>'json',
 							 %opts
@@ -426,7 +430,7 @@ sub ddcQuery {
   my $cli  = $rel->ddcClient();
   $cli->{limit} = $opts{limit}//-1 if (exists($opts{limit}));
 
-  $rel->vlog($level, "$logas: query[server=$rel->{ddcServer},limit=$cli->{limit}]: ",
+  $rel->vlog($level, "$logas: query[server=$rel->{ddcServer},limit=$cli->{limit},timeout=$cli->{timeout}]: ",
 	     ($trunc < 0 || length($qstr) <= $trunc ? $qstr : (substr($qstr,0,$trunc)."...")));
   $cli->open()
     or $rel->logconfess($coldb->{error}="$logas: failed to connect to DDC server on $rel->{ddcServer}: $!")
